<?php

namespace Drupal\prepared_data;

use Drupal\Core\Session\AccountInterface;
use Drupal\prepared_data\Provider\ProviderManager;

/**
 * Defines the factory for prepared data.
 */
class DataFactory implements DataFactoryInterface {

  /**
   * The manager for data provider plugins.
   *
   * @var \Drupal\prepared_data\Provider\ProviderManager
   */
  protected $providerManager;

  /**
   * DataFactory constructor.
   *
   * @param \Drupal\prepared_data\Provider\ProviderManager $provider_manager
   *   The manager for data provider plugins.
   */
  public function __construct(ProviderManager $provider_manager) {
    $this->providerManager = $provider_manager;
  }

  /**
   * {@inheritdoc}
   */
  public function get($argument, $force_valid = FALSE, $force_fresh = FALSE, AccountInterface $account = NULL) {
    $data = NULL;
    foreach ($this->providerManager->getAllProviders() as $provider) {
      $current_user = $provider->getCurrentUser();
      if (isset($account)) {
        $provider->setCurrentUser($account);
      }
      if (TRUE === $force_fresh) {
        $data = $provider->demandFresh($argument);
      }
      else {
        $data = $provider->demand($argument, $force_valid);
      }
      $provider->setCurrentUser($current_user);
      if ($data) {
        break;
      }
    }
    return $data;
  }

}
