<?php

namespace Drupal\prepared_data;

use Drupal\Core\Session\AccountInterface;

/**
 * Interface for prepared data factories.
 */
interface DataFactoryInterface {

  /**
   * Get prepared data for the given argument.
   *
   * The receiving of prepared data includes
   * an access check regards the current user.
   *
   * @param string|array|mixed $argument
   *   Can be a key as string, an associative array of named parameters,
   *   or any kind of object which wants to match.
   * @param bool $force_valid
   *   When TRUE, expired data will be refreshed before it's being returned.
   * @param bool $force_fresh
   *   When set to TRUE, the prepared data will be refreshed
   *   before it's being returned. This should only be considered
   *   when refreshed data is explicitly required.
   *   Default is set to FALSE.
   * @param \Drupal\Core\Session\AccountInterface $account
   *   (Optional) When given, the access check will be performed on
   *   this account, instead of the current user.
   *
   * @return \Drupal\prepared_data\PreparedDataInterface|null
   *   The prepared data as wrapped object, or NULL if access
   *   failed or the parameters don't match up with any provider.
   */
  public function get($argument, $force_valid = FALSE, $force_fresh = FALSE, AccountInterface $account = NULL);

}
